==> image-analysis-util-0.0.11.tar.gz: image-analysis-util-0.0.11/iautil/utilities/ui.py <==
"""
UI widget classes.
"""

# ----------------------------------------------------------------------------------

import pyqtgraph as pg
from pyqtgraph import QtGui, QtCore
import xarray as xr

# ----------------------------------------------------------------------------------

__all__ = (
    "DataArrayImageView",
    "DataArrayPlot"
)

# ----------------------------------------------------------------------------------

class DataArrayImageView(pg.ImageView):
    """
    A custom PyQtGraph ImageView.
    """
    
    def __init__(self, parent=None) -> None:
        super(DataArrayImageView, self).__init__(
            parent, 
            view=pg.PlotItem()
        )

    # ------------------------------------------------------------------------------

    def set_data_array(self, data_array: xr.DataArray):
        """
        
        """

        image = data_array.values
        self.view.setLabels(
            bottom = data_array.dims[0],
            left = data_array.dims[1]
        )
        self.setImage(image)

# ----------------------------------------------------------------------------------

class DataArrayPlot(pg.PlotWidget):
    """
    A custom PyQtGraph PlotWidget.
    """
    
    def __init__(self, parent=None, plotItem=None) -> None:
        super(DataArrayPlot, self).__init__(parent, plotItem)

# ----------------------------------------------------------------------------------

app = pg.mkQApp()
imv = pg.ImageView(view=pg.PlotItem())
imv.view.setLabels(bottom = "X Axis", 
                     left = "Y1 Axis", 
                     right = "Y2 Axis")
imv.show()
app.exec_()

==> image-analysis-util-0.0.15.tar.gz: image-analysis-util-0.0.15/iautil/utilities/ui.py <==
"""
UI widget classes.
"""

# ----------------------------------------------------------------------------------

import pyqtgraph as pg
from pyqtgraph import QtGui, QtCore
import xarray as xr

# ----------------------------------------------------------------------------------

__all__ = (
    "DataArrayImageView",
    "DataArrayPlot"
)

# ----------------------------------------------------------------------------------

class DataArrayImageView(pg.ImageView):
    """
    A custom PyQtGraph ImageView.
    """
    
    def __init__(self, parent=None) -> None:
        super(DataArrayImageView, self).__init__(
            parent, 
            view=pg.PlotItem()
        )

        self.view.setAspectLocked(lock=False)
        self.view.enableAutoRange()

    # ------------------------------------------------------------------------------

    def set_data_array(self, data_array: xr.DataArray):
        """
        
        """

        image = data_array.values
        self.view.setLabels(
            bottom = data_array.dims[0],
            left = data_array.dims[1]
        )

        self.setImage(image)

# ----------------------------------------------------------------------------------

class DataArrayPlot(pg.PlotWidget):
    """
    A custom PyQtGraph PlotWidget.
    """
    
    def __init__(self, parent=None, plotItem=None) -> None:
        super(DataArrayPlot, self).__init__(parent, plotItem)

# ----------------------------------------------------------------------------------
